use jsk2s::Action;


#[cfg(target_os = "windows")]
const USAGE: &str = "
Usage:
    JskDict_mem.exe FILE get KEY
    JskDict_mem.exe FILE delete KEY
    JskDict_mem.exe FILE insert KEY
    JskDict_mem.exe FILE update KEY
    ";

#[cfg(not(target_os = "windows"))]
const USAGE: &str = "
Usage:
    JskDict_mem.exe FILE get KEY
    JskDict_mem.exe FILE delete KEY
    JskDict_mem.exe FILE insert KEY
    JskDict_mem.exe FILE update KEY
    ";


fn main() {
    
    let args: Vec<String> = std::env::args().collect();
    let fname: &String = args.get(1).expect(&USAGE);
    let action:&str = args.get(2).expect(&USAGE).as_ref();
    let key: &str = args.get(3).expect(&USAGE).as_ref();
    let may_be_value: Option<&String> = args.get(4);


    // create a path for the given file
    let path = std::path::Path::new(&fname);
    
    // open the file
    let mut store = Action::open(path).expect("Unable to open the file");
    store.load().expect("Unable to read the data");

    // operations
    match action {
        "get" => match store.get(key.as_bytes()).unwrap() {
            None => eprint!("{:?} Not found", key),
            Some(value) => println!("{:?}", String::from_utf8(value).unwrap()),
        },

        "delete" => store.delete(key.as_bytes()).unwrap(),
        
        "insert" => {
            let value: &str = may_be_value.expect(&USAGE).as_ref();
            store.insert(key.as_bytes(), value.as_bytes()).unwrap()
        },

        "update" => {
            let value: &str = may_be_value.expect(&USAGE).as_ref();
            store.update(key.as_bytes(), value.as_bytes()).unwrap()
        },

        _ => eprint!("{}", USAGE),

    }

    
}